<?php

namespace Drupal\image_sizes;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldDefinitionInterface;


trait ImageSizesFormatterTrait {

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(FieldDefinitionInterface $field_definition) {
    if ($field_definition->getType() == 'entity_reference') {
      if ($field_definition->getSetting('target_type') == 'media') {
        return TRUE;
      }
      return FALSE;
    }
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    foreach ($items as $delta => $item) {
      $item = $this->getField($item);
      if ($item) {
        $elements[$delta] = $this->viewValue($item);
      }
    }
    $elements['#attached']['library'] = ['image_sizes/core'];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public static function getField(FieldItemInterface $item) {
    if ($item->getFieldDefinition()->getType() == 'image') {
      return $item;
    }
    $field = $item->entity->getSource()
      ->getSourceFieldDefinition($item->entity->bundle->entity);
    if ($item->entity->get($field->getName())->isEmpty() || $field->getType() != 'image') {
      return FALSE;
    }
    return $item->entity->get($field->getName())->first();
  }
}
